@@ -360,6 +360,32 @@ class PageRender extends Visitor {
 			else
 				$this->drawTemplateChoice();
 
+		# If mode is modification, use a DefaultForObjectClass template if exaclty 1 matches. Propose the template choice otherwise.
+		} elseif (($this->getMode() == 'modification') && (! isset($_REQUEST['template']))) {
+			if (DEBUGTMP) printf('<font size=-2>%s:<u>%s</u></font><br />',__METHOD__,'DEFAULTFOROBJECTCLASS template if only 1 template matches.');
+
+			$dn = $this->getModeContainer();
+			$server = $this->getServer();
+			$dnojcs = $server->getDNAttrValue($dn,'objectClass');
+			$matchingtmplIDs = array();
+			$unmatchingtmplIDs = array();
+			$tpldefojc = array();
+			foreach ($templates->getTemplates($this->getMode(),$this->getModeContainer(),true) as $tpl) {
+				$tpldefojc = $tpl->getDefaultForObjectClass();
+				if (array_intersect($tpldefojc,$dnojcs)) {
+					array_push($matchingtmplIDs,$tpl->getID());
+				} else {
+					array_push($unmatchingtmplIDs,$tpl->getID());
+				}
+			}
+			if (count($matchingtmplIDs) == 0)       # No matching DefaultForObjectClass found,
+				return 'none';                      # so we use the default template.
+			elseif (count($matchingtmplIDs) == 1)   # Exactly 1 matching DefaultForObjectClass found,
+				return $matchingtmplIDs[0];         # so we use it.
+			elseif (count($unmatchingtmplIDs) == 0) # No template found at all,
+				return 'none';                      # so we use the default template.
+			else                                    # Multiple templates found,
+				$this->drawTemplateChoice();        # so propose the template choice.
 		} else {
 			if (DEBUGTMP) printf('<font size=-2>%s:<u>%s</u></font><br />',__METHOD__,'SELECT a template to use.');
 
@@ -556,7 +582,7 @@ class PageRender extends Visitor {
 	final protected function drawOldValueAttribute($attribute,$i) {
 		if (DEBUGTMP) printf('<font size=-2>%s</font><br />',__METHOD__);
 
-		echo $attribute->getOldValue($i);
+		echo htmlspecialchars($attribute->getOldValue($i));
 	}
 
 	/** DRAW DISPLAYED CURRENT VALUES **/
@@ -827,7 +853,7 @@ class PageRender extends Visitor {
 		if (! $attribute->getOldValue($i))
 			return;
 
-		draw_jpeg_photo($this->getServer(),$this->template->getDN(),$i,$attribute->getName(),false,false);
+		draw_jpeg_photo($this->getServer(),$this->template->getDN(),$attribute->getName(),$i,false,false);
 	}
 
 	/**
@@ -844,16 +870,16 @@ class PageRender extends Visitor {
 		# If the attribute is modified, the new value needs to be stored in a session variable for the draw_jpeg_photo callback.
 		if ($attribute->hasBeenModified()) {
 			$_SESSION['tmp'][$attribute->getName()][$i] = $attribute->getValue($i);
-			draw_jpeg_photo(null,$this->template->getDN(),$i,$attribute->getName(),false,false);
+			draw_jpeg_photo(null,$this->template->getDN(),$attribute->getName(),$i,false,false);
 		} else
-			draw_jpeg_photo($this->getServer(),$this->template->getDN(),$i,$attribute->getName(),false,false);
+			draw_jpeg_photo($this->getServer(),$this->template->getDN(),$attribute->getName(),$i,false,false);
 	}
 
 	protected function drawFormReadOnlyValueJpegAttribute($attribute,$i) {
 		$this->draw('HiddenValue',$attribute,$i);
 		$_SESSION['tmp'][$attribute->getName()][$i] = $attribute->getValue($i);
 
-		draw_jpeg_photo(null,$this->template->getDN(),$i,$attribute->getName(),false,false);
+		draw_jpeg_photo(null,$this->template->getDN(),$attribute->getName(),$i,false,false);
 	}
 
 	protected function drawFormReadOnlyValueMultiLineAttribute($attribute,$i) {
@@ -917,7 +943,12 @@ class PageRender extends Visitor {
 
 	protected function getAutoPostPasswordAttribute($attribute,$i) {
 		# If the password is already encoded, then we'll return
-		if (preg_match('/^\{.+\}.+/',$attribute->getValue($i)))
+		$value = $attribute->getValue($i);
+		if ($value === null) {
+			return;
+		}
+
+		if (preg_match('/^\{.+\}.+/', $value))
 			return;
 
 		$attribute->setPostValue(array('function'=>'PasswordEncrypt','args'=>sprintf('%%enc%%;%%%s%%',$attribute->getName())));
