@@ -504,7 +504,7 @@ class Config {
 
 		$this->default->session['memorylimit'] = array(
 			'desc'=>'Set the PHP memorylimit warning threshold.',
-			'default'=>24);
+			'default'=>'24M');
 
 		$this->default->session['timelimit'] = array(
 			'desc'=>'Set the PHP timelimit.',
@@ -576,6 +576,8 @@ class Config {
 				'ssha512'=>'ssha512',
 				'sha256crypt'=>'sha256crypt',
 				'sha512crypt'=>'sha512crypt',
+				'argon2i'=>'argon2i',
+				'argon2id'=>'argon2id',
 			));
 
 		/** Search display
